@@ -37,7 +37,12 @@ class EC_MS_CONVERTER:
 
 
 def measurement_from_ec_ms_dataset(
-    ec_ms_dict, name=None, cls=ECMSMeasruement, reader=None, **kwargs,
+    ec_ms_dict,
+    name=None,
+    cls=ECMSMeasruement,
+    reader=None,
+    technique=None,
+    **kwargs,
 ):
     """Return an ixdat Measurement with the data from an EC_MS data dictionary.
 
@@ -49,7 +54,8 @@ def measurement_from_ec_ms_dataset(
         ec_ms_dict (dict): The EC_MS data dictionary
         name (str): Name of the measurement
         cls (Measurement class): The class to return a measurement of
-        reader (Reader object): typically what calls this funciton with its read() method
+        reader (Reader object): The class which read ec_ms_dataset from file
+        technique (str): The name of the technique
     """
 
     if "Ewe/V" in ec_ms_dict and "<Ewe>/V" in ec_ms_dict:
@@ -96,12 +102,17 @@ def measurement_from_ec_ms_dataset(
             print(f"Not including '{col}' due to mismatch size with {tseries}")
             continue
         cols_list.append(
-            ValueSeries(name=v_name, data=data, unit_name=unit_name, tseries=tseries,)
+            ValueSeries(
+                name=v_name,
+                data=data,
+                unit_name=unit_name,
+                tseries=tseries,
+            )
         )
 
     obj_as_dict = dict(
         name=name,
-        technique="EC_MS",
+        technique=technique or "EC_MS",
         series_list=cols_list,
         reader=reader,
         tstamp=ec_ms_dict["tstamp"],
