@@ -1,12 +1,13 @@
-from pathlib import Path
 import re
-import pandas as pd
+
 import numpy as np
-from ..data_series import DataSeries, TimeSeries, ValueSeries, Field
-from ..techniques.ec_ms import ECMSMeasurement
-from ..techniques.ms import MSSpectrum
-from .reading_tools import timestamp_string_to_tstamp, FLOAT_MATCH
+import pandas as pd
+
 from .ec_ms_pkl import measurement_from_ec_ms_dataset
+from .reading_tools import timestamp_string_to_tstamp, FLOAT_MATCH
+from ..data_series import DataSeries, TimeSeries, ValueSeries, Field
+from ..techniques import ECMSMeasurement, MSMeasurement, ECMeasurement, Measurement
+from ..techniques.ms import MSSpectrum
 
 ZILIEN_TIMESTAMP_FORM = "%Y-%m-%d %H_%M_%S"  # like 2021-03-15 18_50_10
 
@@ -19,16 +20,27 @@ class ZilienTSVReader:
 
         TODO: This is a hack using EC_MS to read the .tsv. Will be replaced.
         """
-        cls = cls or ECMSMeasurement
+
         from EC_MS import Zilien_Dataset
 
+        if cls is Measurement:
+            cls = ECMSMeasurement
+
+        if "technique" not in kwargs:
+            if issubclass(cls, ECMSMeasurement):
+                kwargs["technique"] = "EC-MS"
+            elif issubclass(cls, ECMeasurement):
+                kwargs["technique"] = "EC"
+            elif issubclass(cls, MSMeasurement):
+                kwargs["technique"] = "MS"
+
         ec_ms_dataset = Zilien_Dataset(path_to_file)
+
         return measurement_from_ec_ms_dataset(
             ec_ms_dataset.data,
             cls=cls,
             name=name,
             reader=self,
-            technique="EC-MS",
             **kwargs,
         )
 
@@ -116,7 +128,11 @@ class ZilienSpectrumReader:
         if path_to_spectrum:
             self.path_to_spectrum = Path(path_to_spectrum)
         cls = cls or MSSpectrum
-        df = pd.read_csv(path_to_spectrum, header=9, delimiter="\t",)
+        df = pd.read_csv(
+            path_to_spectrum,
+            header=9,
+            delimiter="\t",
+        )
         x_name = "Mass  [AMU]"
         y_name = "Current [A]"
         x = df[x_name].to_numpy()
@@ -166,7 +182,8 @@ if __name__ == "__main__":
     )
 
     ecms_measurement = Measurement.read(
-        reader="zilien", path_to_file=path_to_test_file,
+        reader="zilien",
+        path_to_file=path_to_test_file,
     )
 
     ecms_measurement.plot_measurement()
