@@ -13,6 +13,7 @@ from ..constants import (
     MOLECULAR_DIAMETERS,
     MOLAR_MASSES,
 )
+from ..data_series import TimeSeries, ValueSeries
 from ..db import Saveable
 import re
 import numpy as np
@@ -22,7 +23,10 @@ class MSMeasurement(Measurement):
     """Class implementing raw MS functionality"""
 
     extra_column_attrs = {
-        "ms_meaurements": {"mass_aliases", "signal_bgs",},
+        "ms_meaurements": {
+            "mass_aliases",
+            "signal_bgs",
+        },
     }
 
     def __init__(
@@ -54,12 +58,15 @@ class MSMeasurement(Measurement):
         self.tspan_bg = tspan_bg
 
     def __getitem__(self, item):
-        """Adds to Measurement's lookup to check if item is an alias for a mass"""
+        """Try standard lookup, then check if item is a flux or alias for a mass"""
         try:
             return super().__getitem__(item)
         except SeriesNotFoundError:
             if item in self.mass_aliases:
                 return self[self.mass_aliases[item]]
+            if item.startswith("n_"):  # it's a flux!
+                mol = item.split("_")[-1]
+                return self.get_flux_series(mol)
             else:
                 raise
 
@@ -82,7 +89,7 @@ class MSMeasurement(Measurement):
         self,
         signal_name,
         tspan=None,
-        t_bg=None,
+        tspan_bg=None,
         removebackground=False,
         include_endpoints=False,
     ):
@@ -91,32 +98,33 @@ class MSMeasurement(Measurement):
         Args:
             signal_name (str): Name of the signal.
             tspan (list): Timespan for which the signal is returned.
-            t_bg (list): Timespan that corresponds to the background signal.
+            tspan_bg (list): Timespan that corresponds to the background signal.
                 If not given, no background is subtracted.
             removebackground (bool): Whether to remove a pre-set background if available
+                Defaults to False. (Note in grab_flux it defaults to True.)
             include_endpoints (bool): Whether to ensure tspan[0] and tspan[-1] are in t
         """
         time, value = self.grab(
             signal_name, tspan=tspan, include_endpoints=include_endpoints
         )
 
-        if t_bg is None:
+        if tspan_bg is None:
             if removebackground and signal_name in self.signal_bgs:
                 return time, value - self.signal_bgs[signal_name]
             return time, value
 
         else:
-            _, bg = self.grab(signal_name, tspan=t_bg)
+            _, bg = self.grab(signal_name, tspan=tspan_bg)
             return time, value - np.average(bg)
 
-    def grab_cal_signal(self, signal_name, tspan=None, t_bg=None):
+    def grab_cal_signal(self, signal_name, tspan=None, tspan_bg=None):
         """Returns a calibrated signal for a given signal name. Only works if
         calibration dict is not None.
 
         Args:
             signal_name (str): Name of the signal.
             tspan (list): Timespan for which the signal is returned.
-            t_bg (list): Timespan that corresponds to the background signal.
+            tspan_bg (list): Timespan that corresponds to the background signal.
                 If not given, no background is subtracted.
         """
         # TODO: Not final implementation.
@@ -125,7 +133,7 @@ class MSMeasurement(Measurement):
             print("No calibration dict found.")
             return
 
-        time, value = self.grab_signal(signal_name, tspan=tspan, t_bg=t_bg)
+        time, value = self.grab_signal(signal_name, tspan=tspan, tspan_bg=tspan_bg)
 
         return time, value * self.calibration[signal_name]
 
@@ -134,27 +142,35 @@ class MSMeasurement(Measurement):
         mol,
         tspan=None,
         tspan_bg=None,
-        removebackground=False,
+        removebackground=True,
         include_endpoints=False,
     ):
         """Return the flux of mol (calibrated signal) in [mol/s]
 
         Args:
-            mol (str): Name of the molecule.
+            mol (str or MSCalResult): Name of the molecule or a calibration thereof
             tspan (list): Timespan for which the signal is returned.
             tspan_bg (list): Timespan that corresponds to the background signal.
                 If not given, no background is subtracted.
             removebackground (bool): Whether to remove a pre-set background if available
+                Defaults to True.
         """
-        if not self.calibration or mol not in self.calibration:
-            raise QuantificationError(
-                f"Can't quantify {mol} in {self}: Not in calibration={self.calibration}"
-            )
-        mass, F = self.calibration.get_mass_and_F(mol)
+        if isinstance(mol, str):
+            if not self.calibration or mol not in self.calibration:
+                raise QuantificationError(
+                    f"Can't quantify {mol} in {self}: "
+                    f"Not in calibration={self.calibration}"
+                )
+            mass, F = self.calibration.get_mass_and_F(mol)
+        elif isinstance(mol, MSCalResult):
+            mass = mol.mass
+            F = mol.F
+        else:
+            raise TypeError("mol must be str or MSCalResult")
         x, y = self.grab_signal(
             mass,
             tspan=tspan,
-            t_bg=tspan_bg,
+            tspan_bg=tspan_bg,
             removebackground=removebackground,
             include_endpoints=include_endpoints,
         )
@@ -162,7 +178,12 @@ class MSMeasurement(Measurement):
         return x, n_dot
 
     def grab_flux_for_t(
-        self, mol, t, tspan_bg=None, removebackground=False, include_endpoints=False,
+        self,
+        mol,
+        t,
+        tspan_bg=None,
+        removebackground=False,
+        include_endpoints=False,
     ):
         """Return the flux of mol (calibrated signal) in [mol/s] for a given time vec
 
@@ -182,6 +203,17 @@ class MSMeasurement(Measurement):
         y = np.interp(t, t_0, y_0)
         return y
 
+    def get_flux_series(self, mol, tspan=None):
+        """Return a ValueSeries with the calibrated flux of mol during tspan"""
+        t, n_dot = self.grab_flux(mol, tspan=tspan)
+        tseries = TimeSeries(
+            name="n_dot_" + mol + "-t", unit_name="s", data=t, tstamp=self.tstamp
+        )
+        vseries = ValueSeries(
+            name="n_dot_" + mol, unit_name="mol/s", data=n_dot, tseries=tseries
+        )
+        return vseries
+
     def integrate_signal(self, mass, tspan, tspan_bg, ax=None):
         """Integrate a ms signal with background subtraction and evt. plotting
 
@@ -247,10 +279,15 @@ class MSCalResult(Saveable):
     column_attrs = {"name", "mol", "mass", "cal_type", "F"}
 
     def __init__(
-        self, name=None, mol=None, mass=None, cal_type=None, F=None,
+        self,
+        name=None,
+        mol=None,
+        mass=None,
+        cal_type=None,
+        F=None,
     ):
         super().__init__()
-        self.name = name
+        self.name = name or f"{mol} at {mass}"
         self.mol = mol
         self.mass = mass
         self.cal_type = cal_type
@@ -262,6 +299,10 @@ class MSCalResult(Saveable):
             f"mass={self.mass}, F={self.F})"
         )
 
+    @property
+    def color(self):
+        return STANDARD_COLORS[self.mass]
+
 
 class MSInlet:
     """A class for describing the inlet to the mass spec
@@ -367,7 +408,15 @@ class MSInlet:
         return n_dot
 
     def gas_flux_calibration(
-        self, measurement, mol, mass, tspan=None, tspan_bg=None, ax=None,
+        self,
+        measurement,
+        mol,
+        mass,
+        tspan=None,
+        tspan_bg=None,
+        ax=None,
+        carrier_mol=None,
+        mol_conc_ppm=None,
     ):
         """
         Args:
@@ -378,21 +427,44 @@ class MSInlet:
             tspan_bg (iter): Optional timespan at which the signal is at its background.
             ax (matplotlib axis): the axis on which to indicate what signal is used
                 with a thicker line. Defaults to none
+            carrier_mol (str): The name of the molecule of the carrier gas if
+                a dilute analyte is used. Calibration assumes total flux of the
+                capillary is the same as the flux of pure carrier gas. Defaults
+                to None.
+            mol_conc_ppm (float): concentration of the dilute analyte in the carrier gas
+                in ppm. Defaults to None. 
 
         Returns MSCalResult: a calibration result containing the sensitivity factor for
             mol at mass
         """
-        t, S = measurement.grab_signal(mass, tspan=tspan, t_bg=tspan_bg)
+        t, S = measurement.grab_signal(mass, tspan=tspan, tspan_bg=tspan_bg)
         if ax:
             ax.plot(t, S, color=STANDARD_COLORS[mass], linewidth=5)
+        if carrier_mol:
+            if mol_conc_ppm:
+                cal_type="carrier_gas_flux_calibration"
+            else:
+                raise QuantificationError(
+                    "Cannot use carrier gas calibration without analyte"
+                    " concentration. mol_conc_ppm is missing."
+                    )
+        elif mol_conc_ppm:
+            raise QuantificationError(
+                "Cannot use carrier gas calibration without carrier"
+                " gas definition. carrier_mol is missing."
+                )
+        else:
+            cal_type="gas_flux_calibration"
+            mol_conc_ppm=10**6
+            carrier_mol=mol
 
-        n_dot = self.calc_n_dot_0(gas=mol)
+        n_dot = self.calc_n_dot_0(gas=carrier_mol) * mol_conc_ppm / 10**6
         F = np.mean(S) / n_dot
         return MSCalResult(
             name=f"{mol}_{mass}",
             mol=mol,
             mass=mass,
-            cal_type="gas_flux_calibration",
+            cal_type=cal_type,
             F=F,
         )
 
